'use client';

import {
    Box,
    Container,
    Flex,
    Heading,
    Text,
    Divider,
    useColorModeValue,
    Image,
} from '@chakra-ui/react';

import CommentSection from '@/app/components/CommentSection';
import PostDetailPageSidebar from '@/app/components/PostDetailPageSidebar';
import PostDetailPageRelatedPosts from '@/app/components/PostDetailPageRelatedPosts';

export default function BlogPostClient({ post }: { post: any }) {
    const bg = useColorModeValue('gray.50', 'gray.800');
    const titleColor = useColorModeValue('white', 'gray.100');

    return (
        <Box bg={bg} minH="100vh">
            {/* Hero section with image and title overlay */}
            <Box position="relative" boxShadow="lg" overflow="hidden" mb={10}>
                <Image
                    src={post.featured_image}
                    alt={post.title}
                    width="100%"
                    height={{ base: '200px', md: '400px' }}
                    objectFit="cover"
                    borderRadius="0"
                    boxShadow="lg"
                />

                <Heading
                    as="h1"
                    fontSize={{ base: '2xl', md: '5xl' }}
                    color={titleColor}
                    position="absolute"
                    bottom={4}
                    left={4}
                    p={{ base: 2, md: 4 }}
                    pt={{ base: 6, md: 4 }}
                    maxW="100%"
                    mb={4}
                    noOfLines={20}
                >
                    {post.title}
                </Heading>
            </Box>

            <Container maxW="7xl" py={10}>
                <Flex gap={10} direction={{ base: 'column', md: 'row' }}>
                    {/* Main content */}
                    <Box flex={1}>
                        <Text fontSize="md" color="gray.500" mb={6}>
                            {new Date(post.created_at).toLocaleDateString()}
                        </Text>

                        {/* Render the post content as HTML */}
                        <Box
                            className="post-content"
                            dangerouslySetInnerHTML={{ __html: post.content }}
                        />

                        <Divider my={10} />

                        <CommentSection postId={post.id} />

                        <Divider my={10} />

                        <PostDetailPageRelatedPosts currentSlug={post.slug} />
                    </Box>

                    {/* Sidebar on the right */}
                    <Box w={{ base: '100%', md: '25%' }}>
                        <PostDetailPageSidebar />
                    </Box>
                </Flex>
            </Container>
        </Box>
    );
}
